==> monaco-vscode-api-9.0.2.tgz: package/vscode/src/vs/workbench/contrib/comments/browser/commentsAccessibility.js <==
import { ContextKeyExpr } from '../../../../platform/contextkey/common/contextkey.js';
import { IInstantiationService } from '../../../../platform/instantiation/common/instantiation.js';
import { ctxCommentEditorFocused } from './simpleCommentEditor.js';
import { CommentContextKeys } from '../common/commentContextKeys.js';
import { localize } from '../../../../nls.js';
import { AccessibilityVerbositySettingId } from '../../accessibility/browser/accessibilityConfiguration.js';
import { CommentCommandId } from '../common/commentCommandIds.js';
import { ToggleTabFocusModeAction } from '../../../../editor/contrib/toggleTabFocusMode/browser/toggleTabFocusMode.js';
import { AccessibleViewType, AccessibleViewProviderId } from '../../../../platform/accessibility/browser/accessibleView.js';
import { Disposable } from '../../../../base/common/lifecycle.js';
var CommentAccessibilityHelpNLS;
( ((function(CommentAccessibilityHelpNLS) {
    CommentAccessibilityHelpNLS.intro = ( localize(
        5332,
        "The editor contains commentable range(s). Some useful commands include:"
    ));
    CommentAccessibilityHelpNLS.tabFocus = ( localize(
        5333,
        "This widget contains a text area, for composition of new comments, and actions, that can be tabbed to once tab moves focus mode has been enabled with the command Toggle Tab Key Moves Focus{0}.",
        `<keybinding:${ToggleTabFocusModeAction.ID}>`
    ));
    CommentAccessibilityHelpNLS.commentCommands = ( localize(5334, "Some useful comment commands include:"));
    CommentAccessibilityHelpNLS.escape = ( localize(5335, "- Dismiss Comment (Escape)"));
    CommentAccessibilityHelpNLS.nextRange = ( localize(
        5336,
        "- Go to Next Commenting Range{0}.",
        `<keybinding:${CommentCommandId.NextRange}>`
    ));
    CommentAccessibilityHelpNLS.previousRange = ( localize(
        5337,
        "- Go to Previous Commenting Range{0}.",
        `<keybinding:${CommentCommandId.PreviousRange}>`
    ));
    CommentAccessibilityHelpNLS.nextCommentThread = ( localize(
        5338,
        "- Go to Next Comment Thread{0}.",
        `<keybinding:${CommentCommandId.NextThread}>`
    ));
    CommentAccessibilityHelpNLS.previousCommentThread = ( localize(
        5339,
        "- Go to Previous Comment Thread{0}.",
        `<keybinding:${CommentCommandId.PreviousThread}>`
    ));
    CommentAccessibilityHelpNLS.addComment = ( localize(
        5340,
        "- Add Comment on Current Selection{0}.",
        `<keybinding:${CommentCommandId.Add}>`
    ));
    CommentAccessibilityHelpNLS.submitComment = ( localize(5341, "- Submit Comment{0}.", `<keybinding:${CommentCommandId.Submit}>`));
})(CommentAccessibilityHelpNLS || (CommentAccessibilityHelpNLS = {}))));
class CommentsAccessibilityHelpProvider extends Disposable {
    constructor() {
        super(...arguments);
        this.id = AccessibleViewProviderId.Comments;
        this.verbositySettingKey = AccessibilityVerbositySettingId.Comments;
        this.options = { type: AccessibleViewType.Help };
    }
    provideContent() {
        return [CommentAccessibilityHelpNLS.tabFocus, CommentAccessibilityHelpNLS.commentCommands, CommentAccessibilityHelpNLS.escape, CommentAccessibilityHelpNLS.addComment, CommentAccessibilityHelpNLS.submitComment, CommentAccessibilityHelpNLS.nextRange, CommentAccessibilityHelpNLS.previousRange].join('\n');
    }
    onClose() {
        this._element?.focus();
    }
}
class CommentsAccessibilityHelp {
    constructor() {
        this.priority = 110;
        this.name = 'comments';
        this.type = AccessibleViewType.Help;
        this.when = ( (ContextKeyExpr.or(ctxCommentEditorFocused, CommentContextKeys.commentFocused)));
    }
    getProvider(accessor) {
        return accessor.get(IInstantiationService).createInstance(CommentsAccessibilityHelpProvider);
    }
}
export { CommentAccessibilityHelpNLS, CommentsAccessibilityHelp, CommentsAccessibilityHelpProvider };

==> monaco-vscode-api-10.1.0.tgz: package/vscode/src/vs/workbench/contrib/comments/browser/commentsAccessibility.js <==
import { ContextKeyExpr } from '../../../../platform/contextkey/common/contextkey.js';
import { IInstantiationService } from '../../../../platform/instantiation/common/instantiation.js';
import { ctxCommentEditorFocused } from './simpleCommentEditor.js';
import { CommentContextKeys } from '../common/commentContextKeys.js';
import { localize } from '../../../../nls.js';
import { ToggleTabFocusModeAction } from '../../../../editor/contrib/toggleTabFocusMode/browser/toggleTabFocusMode.js';
import { Disposable } from '../../../../base/common/lifecycle.js';
var CommentAccessibilityHelpNLS;
( ((function(CommentAccessibilityHelpNLS) {
    CommentAccessibilityHelpNLS.intro = ( localize(
        5377,
        "The editor contains commentable range(s). Some useful commands include:"
    ));
    CommentAccessibilityHelpNLS.tabFocus = ( localize(
        5378,
        "This widget contains a text area, for composition of new comments, and actions, that can be tabbed to once tab moves focus mode has been enabled with the command Toggle Tab Key Moves Focus{0}.",
        `<keybinding:${ToggleTabFocusModeAction.ID}>`
    ));
    CommentAccessibilityHelpNLS.commentCommands = ( localize(5379, "Some useful comment commands include:"));
    CommentAccessibilityHelpNLS.escape = ( localize(5380, "- Dismiss Comment (Escape)"));
    CommentAccessibilityHelpNLS.nextRange = ( localize(
        5381,
        "- Go to Next Commenting Range{0}.",
        `<keybinding:${"editor.action.nextCommentingRange" }>`
    ));
    CommentAccessibilityHelpNLS.previousRange = ( localize(
        5382,
        "- Go to Previous Commenting Range{0}.",
        `<keybinding:${"editor.action.previousCommentingRange" }>`
    ));
    CommentAccessibilityHelpNLS.nextCommentThread = ( localize(
        5383,
        "- Go to Next Comment Thread{0}.",
        `<keybinding:${"editor.action.nextCommentThreadAction" }>`
    ));
    CommentAccessibilityHelpNLS.previousCommentThread = ( localize(
        5384,
        "- Go to Previous Comment Thread{0}.",
        `<keybinding:${"editor.action.previousCommentThreadAction" }>`
    ));
    CommentAccessibilityHelpNLS.nextCommentedRange = ( localize(
        5385,
        "- Go to Next Commented Range{0}.",
        `<keybinding:${"editor.action.nextCommentedRangeAction" }>`
    ));
    CommentAccessibilityHelpNLS.previousCommentedRange = ( localize(
        5386,
        "- Go to Previous Commented Range{0}.",
        `<keybinding:${"editor.action.previousCommentedRangeAction" }>`
    ));
    CommentAccessibilityHelpNLS.addComment = ( localize(
        5387,
        "- Add Comment on Current Selection{0}.",
        `<keybinding:${"workbench.action.addComment" }>`
    ));
    CommentAccessibilityHelpNLS.submitComment = ( localize(
        5388,
        "- Submit Comment{0}.",
        `<keybinding:${"editor.action.submitComment" }>`
    ));
})(CommentAccessibilityHelpNLS || (CommentAccessibilityHelpNLS = {}))));
class CommentsAccessibilityHelpProvider extends Disposable {
    constructor() {
        super(...arguments);
        this.id = "comments" ;
        this.verbositySettingKey = "accessibility.verbosity.comments" ;
        this.options = { type: "help"  };
    }
    provideContent() {
        return [CommentAccessibilityHelpNLS.tabFocus, CommentAccessibilityHelpNLS.commentCommands, CommentAccessibilityHelpNLS.escape, CommentAccessibilityHelpNLS.addComment, CommentAccessibilityHelpNLS.submitComment, CommentAccessibilityHelpNLS.nextRange, CommentAccessibilityHelpNLS.previousRange].join('\n');
    }
    onClose() {
        this._element?.focus();
    }
}
class CommentsAccessibilityHelp {
    constructor() {
        this.priority = 110;
        this.name = 'comments';
        this.type = "help" ;
        this.when = ( (ContextKeyExpr.or(ctxCommentEditorFocused, CommentContextKeys.commentFocused)));
    }
    getProvider(accessor) {
        return accessor.get(IInstantiationService).createInstance(CommentsAccessibilityHelpProvider);
    }
}
export { CommentAccessibilityHelpNLS, CommentsAccessibilityHelp, CommentsAccessibilityHelpProvider };
